# Table of Contents

- [configuring-integration](<./configuring-integration.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Configuring the Integration](<./Configuring-the-Integration.md>)
  - [Setup in SAP Signavio](<./Configuring-the-Integration/Setup-in-SAP-Signavio.md>)
  - [Minimum Access Rights for Integration](<./Configuring-the-Integration/Minimum-Access-Rights-for-Integration.md>)
  - [Setup in SAP LeanIX](<./Configuring-the-Integration/Setup-in-SAP-LeanIX.md>)
  - [Setting Up Authentication](<./Configuring-the-Integration/Setting-Up-Authentication.md>)
  - [Configuration Name](<./Configuring-the-Integration/Configuration-Name.md>)
  - [SAP Signavio URL](<./Configuring-the-Integration/SAP-Signavio-URL.md>)
  - [Username and Password](<./Configuring-the-Integration/Username-and-Password.md>)
  - [Tenant ID](<./Configuring-the-Integration/Tenant-ID.md>)
  - [Login Parameters](<./Configuring-the-Integration/Login-Parameters.md>)
  - [Managing User](<./Configuring-the-Integration/Managing-User.md>)
